/* $Id: acconfig.h,v 1.4 2002/09/03 22:45:53 qha Exp $ */

/* Define if you have the /dev/random file */
#undef HAVE__DEV_RANDOM

/* Define if you have the /dev/urandom file */
#undef HAVE__DEV_URANDOM

/* Define if you want bogosort to use the /dev/random file */
#undef WANT__DEV_RANDOM

/* Define if you want bogosort to use the /dev/urandom file */
#undef WANT__DEV_URANDOM

/* Define if your C librairy defines 'extern char *sys_errlist[]' */
#undef HAVE_BSD_STYLE_SYS_ERRLIST

/* Define if your C librairy defines 'extern const char *const sys_errlist[]' */
#undef HAVE_GNU_STYLE_SYS_ERRLIST

/* Define if you have the strerror function.  */
#undef HAVE_STRERROR

/* Define if you have the strerror_r function.  */
#undef HAVE_STRERROR_R
